<?php /** @noinspection PhpUndefinedVariableInspection */
if("done"!=$template){ ?>
<label> <input type="submit" name="next" id="next" value="Next &gt;" /></label>
<?php }?>
</form></body></html>